@@ -5,13 +5,25 @@
 #         Смирнова Екатерина <ekanerina@yandex.ru>
 # URL: <https://github.com/SergeyShk/ruTS>
 
-# Метаданные
-
 import io
 import os
 
-version_file = os.path.join(os.path.dirname(__file__), 'VERSION')
-with io.open(version_file, mode='r', encoding='utf-8') as f:
+from .basic_stats import BasicStats
+from .components import (
+    BasicStatsComponent,
+    DiversityStatsComponent,
+    MorphStatsComponent,
+    ReadabilityStatsComponent,
+)
+from .diversity_stats import DiversityStats
+from .extractors import SentsExtractor, WordsExtractor
+from .morph_stats import MorphStats
+from .readability_stats import ReadabilityStats
+
+# Метаданные
+
+version_file = os.path.join(os.path.dirname(__file__), "VERSION")
+with io.open(version_file, mode="r", encoding="utf-8") as f:
     __version__ = f.read().strip()
 
 __doc__ = """Инструмент для извлечения статистик для текстов на русском языке.
@@ -19,16 +31,15 @@ __doc__ = """Инструмент для извлечения статистик
 __author__ = "Шкарин Сергей, Смирнова Екатерина"
 __author_email__ = "kouki.sergey@gmail.com, ekanerina@yandex.ru"
 
-# Импорт основных классов
-
-from .basic_stats import BasicStats
-from .components import (
-    BasicStatsComponent,
-    DiversityStatsComponent,
-    MorphStatsComponent,
-    ReadabilityStatsComponent
-)
-from .diversity_stats import DiversityStats
-from .extractors import SentsExtractor, WordsExtractor
-from .morph_stats import MorphStats
-from .readability_stats import ReadabilityStats
\ No newline at end of file
+__all__ = [
+    "BasicStats",
+    "BasicStatsComponent",
+    "DiversityStatsComponent",
+    "MorphStatsComponent",
+    "ReadabilityStatsComponent",
+    "DiversityStats",
+    "SentsExtractor",
+    "WordsExtractor",
+    "MorphStats",
+    "ReadabilityStats",
+]
