@@ -1,9 +1,18 @@
-from .constants import BASIC_STATS_DESC, COMPLEX_SYL_FACTOR, PUNCTUATIONS, RU_LETTERS, SPACES
+from collections import Counter
+from typing import Dict, Union
+
+from spacy.tokens import Doc
+
+from .constants import (
+    BASIC_STATS_DESC,
+    COMPLEX_SYL_FACTOR,
+    PUNCTUATIONS,
+    RU_LETTERS,
+    SPACES,
+)
 from .extractors import SentsExtractor, WordsExtractor
 from .utils import count_syllables
-from collections import Counter
-from spacy.tokens import Doc
-from typing import Dict, Union
+
 
 class BasicStats(object):
     """
@@ -76,7 +85,7 @@ class BasicStats(object):
         source: Union[str, Doc],
         sents_extractor: SentsExtractor = None,
         words_extractor: WordsExtractor = None,
-        normalize: bool = False
+        normalize: bool = False,
     ):
         if isinstance(source, Doc):
             text = source.text
@@ -85,11 +94,11 @@ class BasicStats(object):
         elif isinstance(source, str):
             text = source
             if not sents_extractor:
-                sents_extractor = SentsExtractor(text)
-            sents = sents_extractor.extract()
+                sents_extractor = SentsExtractor()
+            sents = sents_extractor.extract(text)
             if not words_extractor:
-                words_extractor = WordsExtractor(text)
-            words = words_extractor.extract()
+                words_extractor = WordsExtractor()
+            words = words_extractor.extract(text)
         else:
             raise TypeError("Некорректный источник данных")
         if not words:
@@ -106,8 +115,10 @@ class BasicStats(object):
         self.n_complex_words = sum(1 for spw in syllables_per_word if spw >= COMPLEX_SYL_FACTOR)
         self.n_simple_words = sum(1 for spw in syllables_per_word if COMPLEX_SYL_FACTOR > spw > 0)
         self.n_monosyllable_words = self.c_syllables.get(1, 0)
-        self.n_polysyllable_words = self.n_words - self.c_syllables.get(1, 0) - self.c_syllables.get(0, 0)
-        self.n_chars = len(text.replace('\n', ''))
+        self.n_polysyllable_words = (
+            self.n_words - self.c_syllables.get(1, 0) - self.c_syllables.get(0, 0)
+        )
+        self.n_chars = len(text.replace("\n", ""))
         self.n_letters = sum((1 for char in text if char in RU_LETTERS))
         self.n_spaces = sum((1 for char in text if char in SPACES))
         self.n_syllables = sum(syllables_per_word)
@@ -138,4 +149,4 @@ class BasicStats(object):
         print(f"{'Статистика':^20}|{'Значение':^10}")
         print("-" * 30)
         for stat, value in BASIC_STATS_DESC.items():
-            print(f"{value:20}|{self.get_stats().get(stat):^10}")
\ No newline at end of file
+            print(f"{value:20}|{self.get_stats().get(stat):^10}")
