@@ -1,18 +1,22 @@
-import pymorphy2
 import re
-from .constants import PUNCTUATIONS
 from abc import ABCMeta, abstractmethod
 from collections import Counter
+from typing import Any, Callable, List, Pattern, Tuple, Union
+
+import pymorphy2
 from razdel import sentenize, tokenize
-from typing import Callable, List, Pattern, Tuple, Union
+
+from .constants import PUNCTUATIONS
+
 
 class Extractor(object, metaclass=ABCMeta):
     """
     Абстрактный класс для извлечения объектов из текста
 
     Аргументы:
-        text (str): Строка текста
         tokenizer (pattern|callable): Токенизатор или регулярное выражение
+        min_len (int): Минимальная длина извлекаемого объекта
+        max_len (int): Максимальная длина извлекаемого объекта
 
     Методы:
         extract: Извлечение объектов из текста
@@ -20,17 +24,17 @@ class Extractor(object, metaclass=ABCMeta):
 
     @abstractmethod
     def __init__(
-        self,
-        text: str,
-        tokenizer: Union[Pattern, Callable] = None
+        self, tokenizer: Union[Pattern, Callable] = None, min_len: int = 0, max_len: int = 0
     ):
-        self.text = text
         self.tokenizer = tokenizer
+        self.min_len = min_len
+        self.max_len = max_len
 
     @abstractmethod
     def extract(self) -> Tuple[str, ...]:
         raise NotImplementedError
 
+
 class SentsExtractor(Extractor):
     """
     Класс для извлечения предложений из текста
@@ -39,12 +43,11 @@ class SentsExtractor(Extractor):
         >>> import re
         >>> from ruts import SentsExtractor
         >>> text = "Не имей 100 рублей, а имей 100 друзей"
-        >>> se = SentsExtractor(text, tokenizer=re.compile(r', '))
-        >>> se.extract()
+        >>> se = SentsExtractor(tokenizer=re.compile(r', '))
+        >>> se.extract(text)
         ('Не имей 100 рублей', 'а имей 100 друзей')
 
     Аргументы:
-        text (str): Строка текста
         tokenizer (pattern|callable): Токенизатор или регулярное выражение
         min_len (int): Минимальная длина извлекаемого предложения
         max_len (int): Максимальная длина извлекаемого предложения
@@ -58,35 +61,36 @@ class SentsExtractor(Extractor):
 
     def __init__(
         self,
-        text: str,
         tokenizer: Union[Pattern, Callable] = None,
         min_len: int = 0,
-        max_len: int = 0
+        max_len: int = 0,
     ):
-        super().__init__(text, tokenizer)
-        self.min_len = min_len
-        self.max_len = max_len
+        super().__init__(tokenizer, min_len, max_len)
         if self.min_len and self.max_len and self.min_len > self.max_len:
             raise ValueError("Минимальная длина предложения больше максимальной")
+        self.sents = ()
+        if not self.tokenizer:
+            self.tokenizer = lambda text: (sent.text for sent in sentenize(text))
 
-    def extract(self) -> Tuple[str, ...]:
+    def extract(self, text: str) -> Tuple[str, ...]:
         """
         Извлечение предложений из текста
 
+        Аргументы:
+            text (str): Строка текста
+
         Вывод:
             sents (tuple[str]): Кортеж извлеченных предложений
 
         Исключения:
             TypeError: Если некорректно задан токенизатор
         """
-        if not self.tokenizer:
-            self.sents = (sent.text for sent in sentenize(self.text))
-        elif isinstance(self.tokenizer, Pattern):
-            self.sents = re.split(self.tokenizer, self.text)
+        if isinstance(self.tokenizer, Pattern):
+            self.sents = re.split(self.tokenizer, text)
         else:
             try:
-                self.sents = self.tokenizer(self.text)
-            except:
+                self.sents = self.tokenizer(text)
+            except Exception:
                 raise TypeError("Токенизатор задан некорректно")
         if self.min_len > 0:
             self.sents = (sent for sent in self.sents if len(sent) >= self.min_len)
@@ -94,6 +98,7 @@ class SentsExtractor(Extractor):
             self.sents = (sent for sent in self.sents if len(sent) <= self.max_len)
         return tuple(self.sents)
 
+
 class WordsExtractor(Extractor):
     """
     Класс для извлечения слов из текста
@@ -102,13 +107,12 @@ class WordsExtractor(Extractor):
         >>> from nltk.corpus import stopwords
         >>> from ruts import WordsExtractor
         >>> text = "Не имей 100 рублей, а имей 100 друзей"
-        >>> we = WordsExtractor(text, use_lexemes=True, stopwords=stopwords.words('russian'),
+        >>> we = WordsExtractor(use_lexemes=True, stopwords=stopwords.words('russian'),
         >>>                     filter_nums=True, ngram_range=(1, 2))
-        >>> we.extract()
+        >>> we.extract(text)
         ('иметь', 'рубль', 'иметь', 'друг', 'иметь_рубль', 'рубль_иметь', 'иметь_друг')
 
     Аргументы:
-        text (str): Строка текста
         tokenizer (pattern|callable): Токенизатор или регулярное выражение
         filter_punct (bool): Фильтровать знаки препинания
         filter_nums (bool): Фильтровать числа
@@ -130,7 +134,6 @@ class WordsExtractor(Extractor):
 
     def __init__(
         self,
-        text: str,
         tokenizer: Union[Pattern, Callable] = None,
         filter_punct: bool = True,
         filter_nums: bool = False,
@@ -139,9 +142,9 @@ class WordsExtractor(Extractor):
         lowercase: bool = False,
         ngram_range: Tuple[int, int] = (1, 1),
         min_len: int = 0,
-        max_len: int = 0
+        max_len: int = 0,
     ):
-        super().__init__(text, tokenizer)
+        super().__init__(tokenizer, min_len, max_len)
         self.filter_punct = filter_punct
         self.filter_nums = filter_nums
         self.use_lexemes = use_lexemes
@@ -155,25 +158,31 @@ class WordsExtractor(Extractor):
         if self.min_len and self.max_len and self.min_len > self.max_len:
             raise ValueError("Минимальная длина слова больше максимальной")
         self.words = ()
+        if not self.tokenizer:
+            self.tokenizer = lambda text: (word.text for word in tokenize(text))
 
-    def extract(self) -> Tuple[str, ...]:
+    def extract(
+        self,
+        text: str,
+    ) -> Tuple[str, ...]:
         """
         Извлечение слов из текста
 
+        Аргументы:
+            text (str): Строка текста
+
         Вывод:
             words (tuple[str]): Кортеж извлеченных слов
 
         Исключения:
             TypeError: Если некорректно задан токенизатор
         """
-        if not self.tokenizer:
-            self.words = (word.text for word in tokenize(self.text))
-        elif isinstance(self.tokenizer, Pattern):
-            self.words = (word for word in re.split(self.tokenizer, self.text))
+        if isinstance(self.tokenizer, Pattern):
+            self.words = (word for word in re.split(self.tokenizer, text))
         else:
             try:
-                self.words = (word for word in self.tokenizer(self.text))
-            except:
+                self.words = (word for word in self.tokenizer(text))
+            except Exception:
                 raise TypeError("Токенизатор задан некорректно")
         if self.filter_punct:
             self.words = (word for word in self.words if word not in PUNCTUATIONS)
@@ -195,7 +204,7 @@ class WordsExtractor(Extractor):
             self.words = self.__make_ngrams()
         return tuple(self.words)
 
-    def get_most_common(self, n: int = 10) -> Counter:
+    def get_most_common(self, n: int = 10) -> List[Tuple[Any, int]]:
         """
         Получение счетчика топ-слов
 
@@ -203,7 +212,7 @@ class WordsExtractor(Extractor):
             n (int): Количество слов
 
         Вывод:
-            Counter: Счетчик топ-слов
+            List: Список топ-слов
 
         Исключения:
             ValueError: Если указанное количество слов меньше 0
@@ -219,7 +228,10 @@ class WordsExtractor(Extractor):
         Вывод:
             ngrams (tuple[str]): Кортеж извлеченных N-грамм
         """
-        ngrams = ()
+        ngrams: Tuple[str, ...] = ()
         for n in range(self.ngram_range[0], self.ngram_range[1] + 1):
-            ngrams += tuple('_'.join(self.words[i: i + n]) for i in range(len(self.words) - n + 1))
-        return ngrams
\ No newline at end of file
+            ngrams += tuple(
+                "_".join(tuple(self.words)[i : i + n])
+                for i in range(len(tuple(self.words)) - n + 1)
+            )
+        return ngrams
