@@ -1,12 +1,15 @@
 import os
 import shutil
 import tarfile
-import urllib
+import urllib.parse
+import urllib.request
 import zipfile
-from .constants import RU_VOWELS, DEFAULT_DATA_DIR
 from pathlib import Path
 from typing import Union
 
+from .constants import DEFAULT_DATA_DIR, RU_VOWELS
+
+
 def count_syllables(word: str) -> int:
     """
     Вычисление количества слогов в слове
@@ -19,7 +22,8 @@ def count_syllables(word: str) -> int:
     """
     return sum((1 for char in word if char in RU_VOWELS))
 
-def to_path(path: str) -> Path:
+
+def to_path(path: Union[str, Path]) -> Path:
     """
     Перевод строкового представления пути в объект Path
 
@@ -39,11 +43,12 @@ def to_path(path: str) -> Path:
     else:
         raise TypeError("Некорректно указан путь")
 
+
 def download_file(
     url: str,
     filename: str = None,
     dirpath: Union[str, Path] = DEFAULT_DATA_DIR,
-    force: bool = False
+    force: bool = False,
 ) -> str:
     """
     Загрузка файла из сети
@@ -67,23 +72,21 @@ def download_file(
     filepath = to_path(dirpath).resolve() / filename
     if filepath.is_file() and force is False:
         print(f"Файл {filepath} уже загружен")
-        return None
+        return ""
     else:
         try:
             print(f"Загрузка файла {url}...")
             req = urllib.request.Request(url)
-            with urllib.request.urlopen(req) as response, open(filepath, 'wb') as out_file:
+            with urllib.request.urlopen(req) as response, open(filepath, "wb") as out_file:
                 shutil.copyfileobj(response, out_file)
-        except:
+        except Exception:
             raise RuntimeError("Не удалось загрузить файл")
         else:
             print(f"Файл успешно загружен: {filepath}")
     return str(filepath)
 
-def extract_archive(
-    archive_file: Union[str, Path],
-    extract_dir: Union[str, Path] = None
-) -> str:
+
+def extract_archive(archive_file: Union[str, Path], extract_dir: Union[str, Path] = None) -> str:
     """
     Извлечение файлов из архива в формате ZIP или TAR
 
@@ -103,16 +106,16 @@ def extract_archive(
     is_tar = tarfile.is_tarfile(archive_file)
     if not is_zip and not is_tar:
         print(f"Файл {archive_file} не является архивом в формате ZIP или TAR")
-        return extract_dir
+        return str(extract_dir)
     else:
         print(f"Извлечение файлов из архива {archive_file}...")
         shutil.unpack_archive(archive_file, extract_dir=extract_dir, format=None)
         if is_zip:
-            with zipfile.ZipFile(archive_file, mode='r') as f:
-                members = f.namelist()
+            with zipfile.ZipFile(archive_file, mode="r") as f1:
+                members = f1.namelist()
         else:
-            with tarfile.open(archive_file, mode='r') as f:
-                members = f.getnames()
+            with tarfile.open(archive_file, mode="r") as f2:
+                members = f2.getnames()
         src_basename = os.path.commonpath(members)
         dest_basename = os.path.basename(archive_file)
         if src_basename:
@@ -130,12 +133,11 @@ def extract_archive(
             else:
                 return os.path.join(extract_dir, src_basename)
         else:
-            return extract_dir
+            return str(extract_dir)
+
 
 def safe_divide(
-    num: Union[float, int],
-    den: Union[float, int],
-    default: Union[float, int] = 0
+    num: Union[float, int], den: Union[float, int], default: Union[float, int] = 0
 ) -> float:
     """
     Безопасное деление двух чисел
@@ -151,4 +153,4 @@ def safe_divide(
     if not den:
         return default
     else:
-        return num / den
\ No newline at end of file
+        return num / den
